Method: Debugger::ConditionCommand.help

Defined in:
lib/ruby-debug-ide/commands/condition.rb

.help(cmd) ⇒ Object



40
41
42
43
44
45
46
47
# File 'lib/ruby-debug-ide/commands/condition.rb', line 40

def help(cmd)
  %{
    Condition breakpoint-number expression
Specify breakpoint number N to break only if COND is true.
N is an integer and COND is an expression to be evaluated whenever 
breakpoint N is reached. If the empty string is used, the condition is removed.
  }
end